# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..types import user_advice_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["UserAdvicesResource", "AsyncUserAdvicesResource"]


class UserAdvicesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UserAdvicesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return UserAdvicesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserAdvicesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return UserAdvicesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        advice_type: str,
        description: str,
        image_list: List[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        用户反馈

        Args:
          advice_type: 反馈类型

          description: 反馈内容

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/user-advice",
            body=maybe_transform(
                {
                    "advice_type": advice_type,
                    "description": description,
                    "image_list": image_list,
                },
                user_advice_create_params.UserAdviceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncUserAdvicesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUserAdvicesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CZL-AI/czlai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUserAdvicesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserAdvicesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CZL-AI/czlai-python#with_streaming_response
        """
        return AsyncUserAdvicesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        advice_type: str,
        description: str,
        image_list: List[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        用户反馈

        Args:
          advice_type: 反馈类型

          description: 反馈内容

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/user-advice",
            body=await async_maybe_transform(
                {
                    "advice_type": advice_type,
                    "description": description,
                    "image_list": image_list,
                },
                user_advice_create_params.UserAdviceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class UserAdvicesResourceWithRawResponse:
    def __init__(self, user_advices: UserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = to_raw_response_wrapper(
            user_advices.create,
        )


class AsyncUserAdvicesResourceWithRawResponse:
    def __init__(self, user_advices: AsyncUserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = async_to_raw_response_wrapper(
            user_advices.create,
        )


class UserAdvicesResourceWithStreamingResponse:
    def __init__(self, user_advices: UserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = to_streamed_response_wrapper(
            user_advices.create,
        )


class AsyncUserAdvicesResourceWithStreamingResponse:
    def __init__(self, user_advices: AsyncUserAdvicesResource) -> None:
        self._user_advices = user_advices

        self.create = async_to_streamed_response_wrapper(
            user_advices.create,
        )
