# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ai_meme import AIMeme as AIMeme
from .pet_profile import PetProfile as PetProfile
from .login_response import LoginResponse as LoginResponse
from .medical_record import MedicalRecord as MedicalRecord
from .login_sms_params import LoginSMSParams as LoginSMSParams
from .user_chat_v_params import UserChatVParams as UserChatVParams
from .aidoc_report_params import AidocReportParams as AidocReportParams
from .aipic_report_params import AipicReportParams as AipicReportParams
from .login_wechat_params import LoginWechatParams as LoginWechatParams
from .aipic_options_params import AipicOptionsParams as AipicOptionsParams
from .aipic_summary_params import AipicSummaryParams as AipicSummaryParams
from .upload_create_params import UploadCreateParams as UploadCreateParams
from .user_send_sms_params import UserSendSMSParams as UserSendSMSParams
from .ai_conv_answer_params import AIConvAnswerParams as AIConvAnswerParams
from .ai_meme_create_params import AIMemeCreateParams as AIMemeCreateParams
from .aipic_question_params import AipicQuestionParams as AipicQuestionParams
from .aipic_validate_params import AipicValidateParams as AipicValidateParams
from .ai_trial_answer_params import AITrialAnswerParams as AITrialAnswerParams
from .ai_trial_report_params import AITrialReportParams as AITrialReportParams
from .ai_conv_answer_response import AIConvAnswerResponse as AIConvAnswerResponse
from .ai_conv_relation_params import AIConvRelationParams as AIConvRelationParams
from .ai_conv_validate_params import AIConvValidateParams as AIConvValidateParams
from .ai_meme_create_response import AIMemeCreateResponse as AIMemeCreateResponse
from .ai_meme_generate_params import AIMemeGenerateParams as AIMemeGenerateParams
from .ai_meme_retrieve_params import AIMemeRetrieveParams as AIMemeRetrieveParams
from .ai_trial_history_params import AITrialHistoryParams as AITrialHistoryParams
from .ai_trial_options_params import AITrialOptionsParams as AITrialOptionsParams
from .ai_trial_summary_params import AITrialSummaryParams as AITrialSummaryParams
from .aidoc_pic_result_params import AidocPicResultParams as AidocPicResultParams
from .aipic_pic_result_params import AipicPicResultParams as AipicPicResultParams
from .point_task_bonus_params import PointTaskBonusParams as PointTaskBonusParams
from .ai_checkup_report_params import AICheckupReportParams as AICheckupReportParams
from .ai_trial_answer_response import AITrialAnswerResponse as AITrialAnswerResponse
from .ai_trial_question_params import AITrialQuestionParams as AITrialQuestionParams
from .ai_trial_relation_params import AITrialRelationParams as AITrialRelationParams
from .aidoc_report_task_params import AidocReportTaskParams as AidocReportTaskParams
from .aipic_report_task_params import AipicReportTaskParams as AipicReportTaskParams
from .point_task_list_response import PointTaskListResponse as PointTaskListResponse
from .ai_checkup_summary_params import AICheckupSummaryParams as AICheckupSummaryParams
from .ai_meme_generate_response import AIMemeGenerateResponse as AIMemeGenerateResponse
from .ai_meme_retrieve_response import AIMemeRetrieveResponse as AIMemeRetrieveResponse
from .buriedpoint_create_params import BuriedpointCreateParams as BuriedpointCreateParams
from .check_point_create_params import CheckPointCreateParams as CheckPointCreateParams
from .magnum_key_get_key_params import MagnumKeyGetKeyParams as MagnumKeyGetKeyParams
from .pet_profile_create_params import PetProfileCreateParams as PetProfileCreateParams
from .pet_profile_delete_params import PetProfileDeleteParams as PetProfileDeleteParams
from .pet_profile_list_response import PetProfileListResponse as PetProfileListResponse
from .pet_profile_update_params import PetProfileUpdateParams as PetProfileUpdateParams
from .point_task_confirm_params import PointTaskConfirmParams as PointTaskConfirmParams
from .policy_policy_info_params import PolicyPolicyInfoParams as PolicyPolicyInfoParams
from .user_advice_create_params import UserAdviceCreateParams as UserAdviceCreateParams
from .ai_checkup_is_first_params import AICheckupIsFirstParams as AICheckupIsFirstParams
from .ai_checkup_question_params import AICheckupQuestionParams as AICheckupQuestionParams
from .aidoc_exotic_report_params import AidocExoticReportParams as AidocExoticReportParams
from .aidoc_if_need_image_params import AidocIfNeedImageParams as AidocIfNeedImageParams
from .aipic_exotic_report_params import AipicExoticReportParams as AipicExoticReportParams
from .pet_profile_ex_info_params import PetProfileExInfoParams as PetProfileExInfoParams
from .pet_profile_variety_params import PetProfileVarietyParams as PetProfileVarietyParams
from .upload_image_create_params import UploadImageCreateParams as UploadImageCreateParams
from .whitelist_save_data_params import WhitelistSaveDataParams as WhitelistSaveDataParams
from .ai_checkup_summary_response import AICheckupSummaryResponse as AICheckupSummaryResponse
from .aidoc_exotic_options_params import AidocExoticOptionsParams as AidocExoticOptionsParams
from .aipic_exotic_options_params import AipicExoticOptionsParams as AipicExoticOptionsParams
from .aipic_exotic_summary_params import AipicExoticSummaryParams as AipicExoticSummaryParams
from .pet_profile_delete_response import PetProfileDeleteResponse as PetProfileDeleteResponse
from .pet_profile_retrieve_params import PetProfileRetrieveParams as PetProfileRetrieveParams
from .ai_checkup_is_first_response import AICheckupIsFirstResponse as AICheckupIsFirstResponse
from .ai_checkup_pic_result_params import AICheckupPicResultParams as AICheckupPicResultParams
from .aidoc_exotic_keywords_params import AidocExoticKeywordsParams as AidocExoticKeywordsParams
from .aidoc_exotic_question_params import AidocExoticQuestionParams as AidocExoticQuestionParams
from .aidoc_if_continue_ask_params import AidocIfContinueAskParams as AidocIfContinueAskParams
from .aipic_exotic_question_params import AipicExoticQuestionParams as AipicExoticQuestionParams
from .aipic_exotic_validate_params import AipicExoticValidateParams as AipicExoticValidateParams
from .medical_record_update_params import MedicalRecordUpdateParams as MedicalRecordUpdateParams
from .pet_profile_variety_response import PetProfileVarietyResponse as PetProfileVarietyResponse
from .point_detail_retrieve_params import PointDetailRetrieveParams as PointDetailRetrieveParams
from .user_point_retrieve_response import UserPointRetrieveResponse as UserPointRetrieveResponse
from .ai_checkup_report_task_params import AICheckupReportTaskParams as AICheckupReportTaskParams
from .ai_trial_session_start_params import AITrialSessionStartParams as AITrialSessionStartParams
from .aidoc_exotic_options_response import AidocExoticOptionsResponse as AidocExoticOptionsResponse
from .aidoc_exotic_summarize_params import AidocExoticSummarizeParams as AidocExoticSummarizeParams
from .pet_profile_retrieve_response import PetProfileRetrieveResponse as PetProfileRetrieveResponse
from .point_price_retrieve_response import PointPriceRetrieveResponse as PointPriceRetrieveResponse
from .session_record_history_params import SessionRecordHistoryParams as SessionRecordHistoryParams
from .user_point_cost_report_params import UserPointCostReportParams as UserPointCostReportParams
from .aidoc_exotic_keywords_response import AidocExoticKeywordsResponse as AidocExoticKeywordsResponse
from .aidoc_exotic_pic_result_params import AidocExoticPicResultParams as AidocExoticPicResultParams
from .aidoc_exotic_question_response import AidocExoticQuestionResponse as AidocExoticQuestionResponse
from .aidoc_if_continue_ask_response import AidocIfContinueAskResponse as AidocIfContinueAskResponse
from .aipic_exotic_pic_result_params import AipicExoticPicResultParams as AipicExoticPicResultParams
from .magnum_key_voice_choice_params import MagnumKeyVoiceChoiceParams as MagnumKeyVoiceChoiceParams
from .medical_record_retrieve_params import MedicalRecordRetrieveParams as MedicalRecordRetrieveParams
from .point_detail_retrieve_response import PointDetailRetrieveResponse as PointDetailRetrieveResponse
from .upload_image_oss_create_params import UploadImageOssCreateParams as UploadImageOssCreateParams
from .aidoc_exotic_report_task_params import AidocExoticReportTaskParams as AidocExoticReportTaskParams
from .aipic_exotic_report_task_params import AipicExoticReportTaskParams as AipicExoticReportTaskParams
from .whitelist_filtering_data_params import WhitelistFilteringDataParams as WhitelistFilteringDataParams
from .ai_checkup_update_profile_params import AICheckupUpdateProfileParams as AICheckupUpdateProfileParams
from .aidoc_exotic_ask_continue_params import AidocExoticAskContinueParams as AidocExoticAskContinueParams
from .evaluation_put_evaluation_params import EvaluationPutEvaluationParams as EvaluationPutEvaluationParams
from .magnum_key_picture_choice_params import MagnumKeyPictureChoiceParams as MagnumKeyPictureChoiceParams
from .magnum_key_voice_question_params import MagnumKeyVoiceQuestionParams as MagnumKeyVoiceQuestionParams
from .medical_record_retrieve_response import MedicalRecordRetrieveResponse as MedicalRecordRetrieveResponse
from .ai_checkup_question_result_params import AICheckupQuestionResultParams as AICheckupQuestionResultParams
from .ai_checkup_session_start_response import AICheckupSessionStartResponse as AICheckupSessionStartResponse
from .aidoc_exotic_if_need_image_params import AidocExoticIfNeedImageParams as AidocExoticIfNeedImageParams
from .medical_record_create_list_params import MedicalRecordCreateListParams as MedicalRecordCreateListParams
from .medication_analysis_report_params import MedicationAnalysisReportParams as MedicationAnalysisReportParams
from .ai_checkup_update_profile_response import AICheckupUpdateProfileResponse as AICheckupUpdateProfileResponse
from .aidoc_exotic_ask_continue_response import AidocExoticAskContinueResponse as AidocExoticAskContinueResponse
from .magnum_key_picture_question_params import MagnumKeyPictureQuestionParams as MagnumKeyPictureQuestionParams
from .medication_analysis_summary_params import MedicationAnalysisSummaryParams as MedicationAnalysisSummaryParams
from .medical_record_create_list_response import MedicalRecordCreateListResponse as MedicalRecordCreateListResponse
from .medical_record_ongoing_record_params import MedicalRecordOngoingRecordParams as MedicalRecordOngoingRecordParams
from .medication_analysis_pic_result_params import (
    MedicationAnalysisPicResultParams as MedicationAnalysisPicResultParams,
)
from .user_module_usage_get_add_wecome_bonus_params import (
    UserModuleUsageGetAddWecomeBonusParams as UserModuleUsageGetAddWecomeBonusParams,
)
from .user_module_usage_get_add_wecome_bonus_response import (
    UserModuleUsageGetAddWecomeBonusResponse as UserModuleUsageGetAddWecomeBonusResponse,
)
from .user_module_usage_get_wechat_mini_qrcode_response import (
    UserModuleUsageGetWechatMiniQrcodeResponse as UserModuleUsageGetWechatMiniQrcodeResponse,
)
