# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ContactCreateParams"]


class ContactCreateParams(TypedDict, total=False):
    company_name: str

    contact_name: str

    mobile: str
