# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["PointTaskBonusParams"]


class PointTaskBonusParams(TypedDict, total=False):
    task_id: int
    """任务 id"""
